* Analyse zur Einkommensungleichheit (Maenner vs. Frauen)
* -------------------------------------------------------

version 6.0
set more off
capture log close
log using an1, replace

* Datensatz: SOEP--Daten 1997, Auszug
use data1, clear                           /* siehe (1) */
drop einzug - np9507

* Deskriptive Statistik des Einkommens
summarize ein
mvdecode eink, mv(0)                       /* siehe (2) */
sort sex
by sex:  summarize eink
summarize eink, detail

* Erwerbstaetigkeit nach Geschlecht
label variable est "Erwerbstaetigkeit 97"
label define estlb 1 "Vollzeit" 2 "Teilzeit" 3 "Umschulung" /*
*/  4 "Unregelm"  5 "Wehrd." 6 "n. erw.", modify
label values est estlb
tabulate est sex, col                       /* siehe (3) */

* Vorbereitung Regressionsanalyse
generate men = sex == 1                    /* Geschlecht */
generate vollzeit = est == 1        /* Vollzeit-Teilzeit */
replace vollzeit = . if est >  2            /* siehe (4) */

* Regressionsanalyse I
regress eink men vollzeit

* Grafische Ergebnisdarstellung
predict yhat
sort vollzeit
graph yhat sex, by(vollzeit) symbol(i) connect(l) sort

* Vorbereitung Regressionanalyse II
generate age = 1997 - gebjahr                   /* Alter */
egen miss = rmiss(eink vollzeit men age)
summarize age if miss==0                    /* siehe (5) */
generate age_z = age - r(mean) if miss == 0
gen agemen = age_z * men           /* Alter * Geschlecht */

* Regressionsanalyse II
regress eink men vollzeit age_z agemen

log close
exit

Beschreibung
------------

Analyse zur Einkommensungleichheit (Maennern vs. Frauen).
Hypothesen in Kohler/Kreuter (Kapitel 1 und 2). Haeufigere
Teilzeiterwerbstaetigkeit ist nicht hinreichend zur Erklaerung
der Einkommensungleichheit. Dasselbe gilt fuer das geringere
Durchschnittsalter der erwerbstaetigen Frauen.  Die Ein-
kommensungleichheit ist zwar staerker bei aelteren Personen,
ist aber auch bei juengeren noch deutlich vorhanden.


Notes:
------

(1) SOEP - Lehrstichprobe + zufaellige Auswahl jeweils nur
    einer Person aus jedem Haushalt (Erstellung: crdata1.do).
(2) Personen mit Einkommen von 0 werden ausgeschlossen.
(3) Frauen sind haeufiger teilzeiterwerbstaetig als Maenner,
    der Erwerbsstatus sollte darum kontrolliert werden.
(4) Hierdurch werden nicht erwerbstaetige Personen aus den
    Analysen ausgeschlossen.
(5) Zentrierung wg. Aiken/West (1991)
