* Erzeugt Querschnitts--Datensatz fuer Kohler/Kreuter
* ---------------------------------------------------
* (calls mkdat.ado and holrein.ado)

* Bitte lokalen Makro "soepdir" auf SOEP-Verzeichnis setzen
local soepdir ~/data/soep

version 6.0
clear
set more off
set memory 20m

*-------------------------- DATEN LADEN ----------------------------------
#delimit ;
mkdat
/* Allgemeine Lebenszufriedenheit */
AP6801 BP9301 CP9601 DP9801 EP89  FP108 GP109 HP10901 IP10901 JP10901 KP10401
LP10401 MP11001 NP11701
/* PI j/n */
AP5601 BP7901 CP7901 DP8801 EP7701 FP9301 GP8501 HP9001 IP9001 JP9001 KP9201
LP9801 MP8401 NP9401
/* PI Partei */
AP5602 BP7902 CP7902 DP8802 EP7702 FP9302 GP8502 HP9002 IP9002 JP9002 KP9202
LP9802 MP8402 NP9402
/* PI Intensitaet */
AP5603 BP7903 CP7903 DP8803 EP7703 FP9303 GP8503 HP9003 IP9003 JP9003 KP9203
LP9803 MP8403 NP9403
using `soepdir',
files(p) waves(a b c d e f g h i j k l m n) keep(sex gebjahr) uc ;

holrein
awgurt bwgurt cwgurt dwgurt ewgurt fwgurt gwgurt hwgurt iwgurt
jwgurt kwgurt lwgurt mwgurt nwgurt
awohnfl bwohnfl cwohnfl dwohnfl ewohnfl fwohnfl gwohnfl hwohnfl iwohnfl
jwohnfl kwohnfl lwohnfl mwohnfl nwohnfl
using `soepdir',
files(hgen) waves(a b c d e f g h i j k l m n);

holrein
bhhgr chhgr dhhgr ehhgr fhhgr ghhgr hhhgr ihhgr jhhgr khhgr
lhhgr mhhgr nhhgr
using `soepdir',
 files(hbrutto) waves(b c d e f g h i j k l m n);

holrein
bul84 bul85 bul86 bul87 bul88 bul89 bul90 bul91 bul92 bul93 bul94 bul95 bul96
bul97
using `soepdir', files(peigen) waves(a b c d e f g h i j k l m n) ;


holrein
ahhgr
using `soepdir',
 files(h) waves(a);

#delimit cr

*--------------------- LEHRSTICHPROBE----------------------------------
save 11, replace
use hhnr rgroup using `soepdir'/cirdef
sort hhnr
save 12, replace
use 11
sort hhnr
merge hhnr using 12
keep if rgroup20 >= 11 & rgroup20 <= 20
drop if _merge == 2
drop rgroup20 _merge
erase 11.dta
erase 12.dta

* -------------------NUR 1 PERSON PRO HAUSHALT IN WELLE 1 --------------
set seed 731
gen r = uniform()
sort ahhnr r
quietly by ahhnr: keep if _n == 1
drop hhnr ahhnr - nnetto r

*----------------------------KOSMETIK-----------------------------------

* Programm zum Umbenennen der Variablen
* -------------------------------------

capture program drop umben
program define umben
        version 6.0
        local name "`1'"
        macro shift
        local i 84
        while "`1'" ~= "" {
            ren `1' `name'`i'
            note `name'`i': Ursprung: `1'
            local i = `i' + 1
            mac shift
        }
end

* Wohnungsvariablen
* -----------------

* Beurteilung Wohnungsgroesse
umben wgurt awgurt bwgurt cwgurt dwgurt ewgurt fwgurt gwgurt /*
*/ hwgurt iwgurt jwgurt kwgurt lwgurt mwgurt nwgurt
for num 84/97: lab var wgurtX "Wohnungsgroesse, Beurteilung HV X"
for num 84/97: lab val wgurtX wgurt
lab def wgurt 1 "v.z.kl." 2 "zu klein" 3 "richtig" 4 "zu gross" /*
*/ 5 "v.z.gr."

* Wohnungsgroesse
umben wohngr awohnfl bwohnfl cwohnfl dwohnfl ewohnfl fwohnfl /*
*/ gwohnfl hwohnfl iwohnfl jwohnfl kwohnfl lwohnfl mwohnfl nwohnfl
for num 84/97: lab var wohngrX "Wohnungsgroesse in qm X"


* Haushaltsgroesse
* ----------------

umben hhgr ahhgr bhhgr chhgr dhhgr ehhgr fhhgr ghhgr hhhgr ihhgr /*
*/ jhhgr khhgr lhhgr mhhgr nhhgr
for num 84/97: lab var hhgrX "Haushaltsgroesse"


*------------------------MISSING - VALUES -------------------------------
mvdecode _all, mv(-3)
mvdecode _all, mv(-2)
mvdecode _all, mv(-1)

* ---------------------ALLGEMEINE VALUE LABELS----------------------------
lab def janein 1 "ja" 2 "nein"
lab def yesno 0 "nein" 1 "ja"
lab def zuf 0 "s. unzuf" 10 "s. zufr."
lab def sor 1 "grosse S" 2 "einige S" 3 "keine S."

*------------------------SPEICHERN DATA1A-----------------------------
#delimit ;
order
persnr sex gebjahr wgurt* wohngr* hhgr84 hhgr85-hhgr97
ap6801 bp9301 cp9601 dp9801 ep89  fp108 gp109 hp10901 ip10901 jp10901 kp10401
lp10401 mp11001 np11701
ap5601 bp7901 cp7901 dp8801 ep7701 fp9301 gp8501 hp9001 ip9001 jp9001 kp9201
lp9801 mp8401 np9401
ap5602 bp7902 cp7902 dp8802 ep7702 fp9302 gp8502 hp9002 ip9002 jp9002 kp9202
lp9802 mp8402 np9402
ap5603 bp7903 cp7903 dp8803 ep7703 fp9303 gp8503 hp9003 ip9003 jp9003 kp9203
lp9803 mp8403 np9403 ;
#delimit cr

label data "SOEP 84 - 97 (Auszug)"
save data2a, replace old

*---------------------------VERFREMDUNG--------------------------------

* Metrische Variablen
* -------------------

* Programm
capture program drop noise1
program define noise1
version 6.0
syntax varlist
tokenize `varlist'
set seed 731
tempvar fx
gen `fx' = .
        while "`1'" ~= "" {
                quietly sum `1', d
                local range = r(p99) - r(p1)
                local a 1/sqrt(2*_pi*r(Var))
                replace `fx' =  `a' * exp((`1'-r(mean))^2/(2*r(Var))*-1)
                quietly sum `fx'
                local s = (.3 * `range')/(3 * r(max))
                replace `1'=abs(round(`1'+`s'*invnorm(uniform())*`fx',1))
                macro shift
        }
end
noise1 gebjahr wohngr84-wohngr97

* Kategoriale Variablen
* ---------------------

* Program
capture program drop noise2
program define noise2
version 6.0
syntax varlist
tokenize `varlist'
        set seed 731
        tempvar r
        gen `r' = .
        while "`1'" ~= "" {
                replace `r' = uniform()
                replace `1' = `1'[int(uniform()*_N + 1)] if `r' < .3
                mac shift
        }
end

noise2 sex bul84 - bul97 hhgr84 - hhgr97

* Persnr (Persnr 1 - 3340 aus didaktischen Gruenden unerwuenscht)
generate r = uniform()
sort r
quietly sum persnr
gen schritt = int((r(max) - r(min))/r(N))
replace persnr = sum(schritt) + int(invnorm(uniform()) * 100)
drop r schritt


* Korrekturen
* -----------

replace gebjahr = 1968 - int(uniform()*4 +1) if gebjahr > 1968
save data2, replace

* Langer Datensatz
* ----------------

keep persnr sex gebjahr wgurt* wohngr* hhgr*
reshape long wgurt wohngr hhgr, i(persnr) j(welle)
iis persnr
tis welle

save data2l, replace

exit
